# Generated by Django 2.1.5 on 2019-02-14 08:04

import uuid

from django.db import migrations, models

import katka.fields


class Migration(migrations.Migration):

    dependencies = [
        ("katka", "0004_credential_secret"),
    ]

    operations = [
        migrations.CreateModel(
            name="SCMService",
            fields=[
                ("created", models.DateTimeField(auto_now_add=True)),
                ("created_username", katka.fields.AutoUsernameField(max_length=50)),
                ("modified", models.DateTimeField(auto_now=True)),
                ("modified_username", katka.fields.AutoUsernameField(max_length=50)),
                (
                    "status",
                    models.CharField(
                        choices=[("active", "active"), ("inactive", "inactive")], default="active", max_length=50
                    ),
                ),
                (
                    "public_identifier",
                    models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False),
                ),
                ("type", models.CharField(max_length=48)),
                ("server_url", models.URLField()),
            ],
            options={"abstract": False,},
        ),
    ]
